"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Diagnose = void 0;
const bc_minecraft_bedrock_project_1 = require("bc-minecraft-bedrock-project");
const Json_1 = require("../../Json/Json");
const Manifest_1 = require("../../Minecraft/Manifest");
const bc_minecraft_bedrock_types_1 = require("bc-minecraft-bedrock-types");
const main_1 = require("../../../../main");
/**Diagnoses the given document as an bp manifest
 * @param doc The text document to diagnose
 * @param diagnoser The diagnoser builder to receive the errors*/
function Diagnose(doc, diagnoser) {
    const manifest = Json_1.Json.LoadReport(doc, diagnoser);
    if (!Json_1.Json.TypeCheck(manifest, diagnoser, "manifest", "minecraft.manifest.invalid", bc_minecraft_bedrock_project_1.Internal.Manifest.is))
        return;
    (0, Manifest_1.minecraft_manifest_diagnose)(manifest, diagnoser);
    (0, Manifest_1.minecraft_manifest_required_module)(manifest, diagnoser, "data");
    //BP specific
    check_min_engine_version(manifest.header.min_engine_version, doc, diagnoser);
}
exports.Diagnose = Diagnose;
function check_min_engine_version(version, doc, diagnoser) {
    const pack = diagnoser.context.getCache().BehaviorPacks.get(doc);
    /**No pack then skip */
    if (pack === undefined)
        return;
    /**Only need to check if there are functions */
    if (pack.functions.count() === 0)
        return;
    if (version !== undefined) {
        if (bc_minecraft_bedrock_types_1.Types.Version.compare(version, { major: 1, minor: 8, patch: 0 }) >= 0)
            return;
    }
    return diagnoser.Add("header", "Behaviorpacks with mcfunctions need `min_engine_version` of atleast value: '1.8.0'", main_1.DiagnosticSeverity.error, "behaviorpack.manifest.min_engine_version");
}
//# sourceMappingURL=entry.js.map